==> pulumi-aws-kotlin-6.13.1.0-sources.jar: com/pulumi/aws/fsx/kotlin/inputs/OntapStorageVirtualMachineActiveDirectoryConfigurationSelfManagedActiveDirectoryConfigurationArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.fsx.kotlin.inputs

import com.pulumi.aws.fsx.inputs.OntapStorageVirtualMachineActiveDirectoryConfigurationSelfManagedActiveDirectoryConfigurationArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 *
 * @property dnsIps A list of up to three IP addresses of DNS servers or domain controllers in the self-managed AD directory.
 * @property domainName The fully qualified domain name of the self-managed AD directory. For example, `corp.example.com`.
 * @property fileSystemAdministratorsGroup The name of the domain group whose members are granted administrative privileges for the SVM. The group that you specify must already exist in your domain. Defaults to `Domain Admins`.
 * @property organizationalUnitDistinguishedName The fully qualified distinguished name of the organizational unit within your self-managed AD directory that the Windows File Server instance will join. For example, `OU=FSx,DC=yourdomain,DC=corp,DC=com`. Only accepts OU as the direct parent of the SVM. If none is provided, the SVM is created in the default location of your self-managed AD directory. To learn more, see [RFC 2253](https://tools.ietf.org/html/rfc2253).
 * @property password The password for the service account on your self-managed AD domain that Amazon FSx will use to join to your AD domain.
 * @property username The user name for the service account on your self-managed AD domain that Amazon FSx will use to join to your AD domain.
 */
public data class
OntapStorageVirtualMachineActiveDirectoryConfigurationSelfManagedActiveDirectoryConfigurationArgs(
    public val dnsIps: Output<List<String>>,
    public val domainName: Output<String>,
    public val fileSystemAdministratorsGroup: Output<String>? = null,
    public val organizationalUnitDistinguishedName: Output<String>? = null,
    public val password: Output<String>,
    public val username: Output<String>,
) :
    ConvertibleToJava<com.pulumi.aws.fsx.inputs.OntapStorageVirtualMachineActiveDirectoryConfigurationSelfManagedActiveDirectoryConfigurationArgs> {
    override fun toJava():
        com.pulumi.aws.fsx.inputs.OntapStorageVirtualMachineActiveDirectoryConfigurationSelfManagedActiveDirectoryConfigurationArgs =
        com.pulumi.aws.fsx.inputs.OntapStorageVirtualMachineActiveDirectoryConfigurationSelfManagedActiveDirectoryConfigurationArgs.builder()
            .dnsIps(dnsIps.applyValue({ args0 -> args0.map({ args0 -> args0 }) }))
            .domainName(domainName.applyValue({ args0 -> args0 }))
            .fileSystemAdministratorsGroup(fileSystemAdministratorsGroup?.applyValue({ args0 -> args0 }))
            .organizationalUnitDistinguishedName(
                organizationalUnitDistinguishedName?.applyValue({ args0 ->
                    args0
                }),
            )
            .password(password.applyValue({ args0 -> args0 }))
            .username(username.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [OntapStorageVirtualMachineActiveDirectoryConfigurationSelfManagedActiveDirectoryConfigurationArgs].
 */
@PulumiTagMarker
public class
OntapStorageVirtualMachineActiveDirectoryConfigurationSelfManagedActiveDirectoryConfigurationArgsBuilder
internal constructor() {
    private var dnsIps: Output<List<String>>? = null

    private var domainName: Output<String>? = null

    private var fileSystemAdministratorsGroup: Output<String>? = null

    private var organizationalUnitDistinguishedName: Output<String>? = null

    private var password: Output<String>? = null

    private var username: Output<String>? = null

    /**
     * @param value A list of up to three IP addresses of DNS servers or domain controllers in the self-managed AD directory.
     */
    @JvmName("iidoyfaihqvxgqdi")
    public suspend fun dnsIps(`value`: Output<List<String>>) {
        this.dnsIps = value
    }

    @JvmName("klcoykuybvnbllfb")
    public suspend fun dnsIps(vararg values: Output<String>) {
        this.dnsIps = Output.all(values.asList())
    }

    /**
     * @param values A list of up to three IP addresses of DNS servers or domain controllers in the self-managed AD directory.
     */
    @JvmName("ptqqjyobhwgqajdm")
    public suspend fun dnsIps(values: List<Output<String>>) {
        this.dnsIps = Output.all(values)
    }

    /**
     * @param value The fully qualified domain name of the self-managed AD directory. For example, `corp.example.com`.
     */
    @JvmName("loikmkrnktiffmer")
    public suspend fun domainName(`value`: Output<String>) {
        this.domainName = value
    }

    /**
     * @param value The name of the domain group whose members are granted administrative privileges for the SVM. The group that you specify must already exist in your domain. Defaults to `Domain Admins`.
     */
    @JvmName("wbxcxhnbpopbpaey")
    public suspend fun fileSystemAdministratorsGroup(`value`: Output<String>) {
        this.fileSystemAdministratorsGroup = value
    }

    /**
     * @param value The fully qualified distinguished name of the organizational unit within your self-managed AD directory that the Windows File Server instance will join. For example, `OU=FSx,DC=yourdomain,DC=corp,DC=com`. Only accepts OU as the direct parent of the SVM. If none is provided, the SVM is created in the default location of your self-managed AD directory. To learn more, see [RFC 2253](https://tools.ietf.org/html/rfc2253).
     */
    @JvmName("ooslexvhlcqiapnt")
    public suspend fun organizationalUnitDistinguishedName(`value`: Output<String>) {
        this.organizationalUnitDistinguishedName = value
    }

    /**
     * @param value The password for the service account on your self-managed AD domain that Amazon FSx will use to join to your AD domain.
     */
    @JvmName("qvxrkivsnntyrbhg")
    public suspend fun password(`value`: Output<String>) {
        this.password = value
    }

    /**
     * @param value The user name for the service account on your self-managed AD domain that Amazon FSx will use to join to your AD domain.
     */
    @JvmName("orcserjpmonwrpmr")
    public suspend fun username(`value`: Output<String>) {
        this.username = value
    }

    /**
     * @param value A list of up to three IP addresses of DNS servers or domain controllers in the self-managed AD directory.
     */
    @JvmName("qldroscpbdjrrscn")
    public suspend fun dnsIps(`value`: List<String>) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.dnsIps = mapped
    }

    /**
     * @param values A list of up to three IP addresses of DNS servers or domain controllers in the self-managed AD directory.
     */
    @JvmName("kvnbbigipjxbhdcx")
    public suspend fun dnsIps(vararg values: String) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.dnsIps = mapped
    }

    /**
     * @param value The fully qualified domain name of the self-managed AD directory. For example, `corp.example.com`.
     */
    @JvmName("ohpcctlbyqlxwqnw")
    public suspend fun domainName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.domainName = mapped
    }

    /**
     * @param value The name of the domain group whose members are granted administrative privileges for the SVM. The group that you specify must already exist in your domain. Defaults to `Domain Admins`.
     */
    @JvmName("uvsmsxnunmvpobxe")
    public suspend fun fileSystemAdministratorsGroup(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.fileSystemAdministratorsGroup = mapped
    }

    /**
     * @param value The fully qualified distinguished name of the organizational unit within your self-managed AD directory that the Windows File Server instance will join. For example, `OU=FSx,DC=yourdomain,DC=corp,DC=com`. Only accepts OU as the direct parent of the SVM. If none is provided, the SVM is created in the default location of your self-managed AD directory. To learn more, see [RFC 2253](https://tools.ietf.org/html/rfc2253).
     */
    @JvmName("edrcysrjvchpyryv")
    public suspend fun organizationalUnitDistinguishedName(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.organizationalUnitDistinguishedName = mapped
    }

    /**
     * @param value The password for the service account on your self-managed AD domain that Amazon FSx will use to join to your AD domain.
     */
    @JvmName("dklvqoqxuqiarodu")
    public suspend fun password(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.password = mapped
    }

    /**
     * @param value The user name for the service account on your self-managed AD domain that Amazon FSx will use to join to your AD domain.
     */
    @JvmName("pyieawtkjmsyevfc")
    public suspend fun username(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.username = mapped
    }

    internal fun build():
        OntapStorageVirtualMachineActiveDirectoryConfigurationSelfManagedActiveDirectoryConfigurationArgs =
        OntapStorageVirtualMachineActiveDirectoryConfigurationSelfManagedActiveDirectoryConfigurationArgs(
            dnsIps = dnsIps ?: throw PulumiNullFieldException("dnsIps"),
            domainName = domainName ?: throw PulumiNullFieldException("domainName"),
            fileSystemAdministratorsGroup = fileSystemAdministratorsGroup,
            organizationalUnitDistinguishedName = organizationalUnitDistinguishedName,
            password = password ?: throw PulumiNullFieldException("password"),
            username = username ?: throw PulumiNullFieldException("username"),
        )
}

==> pulumi-aws-kotlin-6.49.1.0-sources.jar: com/pulumi/aws/fsx/kotlin/inputs/OntapStorageVirtualMachineActiveDirectoryConfigurationSelfManagedActiveDirectoryConfigurationArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.fsx.kotlin.inputs

import com.pulumi.aws.fsx.inputs.OntapStorageVirtualMachineActiveDirectoryConfigurationSelfManagedActiveDirectoryConfigurationArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 *
 * @property dnsIps A list of up to three IP addresses of DNS servers or domain controllers in the self-managed AD directory.
 * @property domainName The fully qualified domain name of the self-managed AD directory. For example, `corp.example.com`.
 * @property fileSystemAdministratorsGroup The name of the domain group whose members are granted administrative privileges for the SVM. The group that you specify must already exist in your domain. Defaults to `Domain Admins`.
 * @property organizationalUnitDistinguishedName The fully qualified distinguished name of the organizational unit within your self-managed AD directory that the Windows File Server instance will join. For example, `OU=FSx,DC=yourdomain,DC=corp,DC=com`. Only accepts OU as the direct parent of the SVM. If none is provided, the SVM is created in the default location of your self-managed AD directory. To learn more, see [RFC 2253](https://tools.ietf.org/html/rfc2253).
 * @property password The password for the service account on your self-managed AD domain that Amazon FSx will use to join to your AD domain.
 * @property username The user name for the service account on your self-managed AD domain that Amazon FSx will use to join to your AD domain.
 */
public data class
OntapStorageVirtualMachineActiveDirectoryConfigurationSelfManagedActiveDirectoryConfigurationArgs(
    public val dnsIps: Output<List<String>>,
    public val domainName: Output<String>,
    public val fileSystemAdministratorsGroup: Output<String>? = null,
    public val organizationalUnitDistinguishedName: Output<String>? = null,
    public val password: Output<String>,
    public val username: Output<String>,
) :
    ConvertibleToJava<com.pulumi.aws.fsx.inputs.OntapStorageVirtualMachineActiveDirectoryConfigurationSelfManagedActiveDirectoryConfigurationArgs> {
    override fun toJava(): com.pulumi.aws.fsx.inputs.OntapStorageVirtualMachineActiveDirectoryConfigurationSelfManagedActiveDirectoryConfigurationArgs =
        com.pulumi.aws.fsx.inputs.OntapStorageVirtualMachineActiveDirectoryConfigurationSelfManagedActiveDirectoryConfigurationArgs.builder()
            .dnsIps(dnsIps.applyValue({ args0 -> args0.map({ args0 -> args0 }) }))
            .domainName(domainName.applyValue({ args0 -> args0 }))
            .fileSystemAdministratorsGroup(fileSystemAdministratorsGroup?.applyValue({ args0 -> args0 }))
            .organizationalUnitDistinguishedName(
                organizationalUnitDistinguishedName?.applyValue({ args0 ->
                    args0
                }),
            )
            .password(password.applyValue({ args0 -> args0 }))
            .username(username.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [OntapStorageVirtualMachineActiveDirectoryConfigurationSelfManagedActiveDirectoryConfigurationArgs].
 */
@PulumiTagMarker
public class
OntapStorageVirtualMachineActiveDirectoryConfigurationSelfManagedActiveDirectoryConfigurationArgsBuilder
internal constructor() {
    private var dnsIps: Output<List<String>>? = null

    private var domainName: Output<String>? = null

    private var fileSystemAdministratorsGroup: Output<String>? = null

    private var organizationalUnitDistinguishedName: Output<String>? = null

    private var password: Output<String>? = null

    private var username: Output<String>? = null

    /**
     * @param value A list of up to three IP addresses of DNS servers or domain controllers in the self-managed AD directory.
     */
    @JvmName("ucmifwpghneiyyxb")
    public suspend fun dnsIps(`value`: Output<List<String>>) {
        this.dnsIps = value
    }

    @JvmName("axfwsekxxjusbpwp")
    public suspend fun dnsIps(vararg values: Output<String>) {
        this.dnsIps = Output.all(values.asList())
    }

    /**
     * @param values A list of up to three IP addresses of DNS servers or domain controllers in the self-managed AD directory.
     */
    @JvmName("ggrjjjsmqaatwyih")
    public suspend fun dnsIps(values: List<Output<String>>) {
        this.dnsIps = Output.all(values)
    }

    /**
     * @param value The fully qualified domain name of the self-managed AD directory. For example, `corp.example.com`.
     */
    @JvmName("nhoqgqclosjsvqxs")
    public suspend fun domainName(`value`: Output<String>) {
        this.domainName = value
    }

    /**
     * @param value The name of the domain group whose members are granted administrative privileges for the SVM. The group that you specify must already exist in your domain. Defaults to `Domain Admins`.
     */
    @JvmName("outrslskjaamvqwe")
    public suspend fun fileSystemAdministratorsGroup(`value`: Output<String>) {
        this.fileSystemAdministratorsGroup = value
    }

    /**
     * @param value The fully qualified distinguished name of the organizational unit within your self-managed AD directory that the Windows File Server instance will join. For example, `OU=FSx,DC=yourdomain,DC=corp,DC=com`. Only accepts OU as the direct parent of the SVM. If none is provided, the SVM is created in the default location of your self-managed AD directory. To learn more, see [RFC 2253](https://tools.ietf.org/html/rfc2253).
     */
    @JvmName("vhmpjfaoaxcocoal")
    public suspend fun organizationalUnitDistinguishedName(`value`: Output<String>) {
        this.organizationalUnitDistinguishedName = value
    }

    /**
     * @param value The password for the service account on your self-managed AD domain that Amazon FSx will use to join to your AD domain.
     */
    @JvmName("bdhisnhebcvfajhi")
    public suspend fun password(`value`: Output<String>) {
        this.password = value
    }

    /**
     * @param value The user name for the service account on your self-managed AD domain that Amazon FSx will use to join to your AD domain.
     */
    @JvmName("hwjqplgqwafafcma")
    public suspend fun username(`value`: Output<String>) {
        this.username = value
    }

    /**
     * @param value A list of up to three IP addresses of DNS servers or domain controllers in the self-managed AD directory.
     */
    @JvmName("hlyljljdkrqxkxed")
    public suspend fun dnsIps(`value`: List<String>) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.dnsIps = mapped
    }

    /**
     * @param values A list of up to three IP addresses of DNS servers or domain controllers in the self-managed AD directory.
     */
    @JvmName("ahhvdgacmkeiosma")
    public suspend fun dnsIps(vararg values: String) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.dnsIps = mapped
    }

    /**
     * @param value The fully qualified domain name of the self-managed AD directory. For example, `corp.example.com`.
     */
    @JvmName("purlabwvfbrilyyr")
    public suspend fun domainName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.domainName = mapped
    }

    /**
     * @param value The name of the domain group whose members are granted administrative privileges for the SVM. The group that you specify must already exist in your domain. Defaults to `Domain Admins`.
     */
    @JvmName("wovjkeobgtwwtyhw")
    public suspend fun fileSystemAdministratorsGroup(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.fileSystemAdministratorsGroup = mapped
    }

    /**
     * @param value The fully qualified distinguished name of the organizational unit within your self-managed AD directory that the Windows File Server instance will join. For example, `OU=FSx,DC=yourdomain,DC=corp,DC=com`. Only accepts OU as the direct parent of the SVM. If none is provided, the SVM is created in the default location of your self-managed AD directory. To learn more, see [RFC 2253](https://tools.ietf.org/html/rfc2253).
     */
    @JvmName("uoqyaldnyemixemg")
    public suspend fun organizationalUnitDistinguishedName(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.organizationalUnitDistinguishedName = mapped
    }

    /**
     * @param value The password for the service account on your self-managed AD domain that Amazon FSx will use to join to your AD domain.
     */
    @JvmName("bgirexwstorcwoiw")
    public suspend fun password(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.password = mapped
    }

    /**
     * @param value The user name for the service account on your self-managed AD domain that Amazon FSx will use to join to your AD domain.
     */
    @JvmName("wrgyrwlohgpkobop")
    public suspend fun username(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.username = mapped
    }

    internal fun build(): OntapStorageVirtualMachineActiveDirectoryConfigurationSelfManagedActiveDirectoryConfigurationArgs =
        OntapStorageVirtualMachineActiveDirectoryConfigurationSelfManagedActiveDirectoryConfigurationArgs(
            dnsIps = dnsIps ?: throw PulumiNullFieldException("dnsIps"),
            domainName = domainName ?: throw PulumiNullFieldException("domainName"),
            fileSystemAdministratorsGroup = fileSystemAdministratorsGroup,
            organizationalUnitDistinguishedName = organizationalUnitDistinguishedName,
            password = password ?: throw PulumiNullFieldException("password"),
            username = username ?: throw PulumiNullFieldException("username"),
        )
}
